@@ -381,17 +381,11 @@ def Muestra_uni(df1,df2,cve,ant):
 
 def indexacion(df,mini,maxi):
     years1=[]
-    years2=[]
     for i in range(mini,maxi,10):
         years1.append(i)
-    for j in range(mini,maxi,5):
-        years2.append(j)
     if maxi not in years1:
         years1.append(maxi)
-    if maxi not in years2:
-        years2.append(maxi)
     conditionlist1=[]
-    conditionlist2=[]
     for k in range(0,(len(years1))-2): 
         c=(df['antiguedad'] >=years1[k]) & (df['antiguedad'] <years1[k+1])
         conditionlist1.append(c)
@@ -399,65 +393,32 @@ def indexacion(df,mini,maxi):
     conditionlist1.append(c)
     L=["A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","W","X","Y","Z"]
     vectorS1=[]
-    vectorS2=[]
     for i in range(0,len(years1)-2):
         vectorS1.append(L[i]+str(years1[i])+"/"+str(years1[i+1]-1))
     vectorS1.append(L[len(years1)-2]+str(years1[len(years1)-2])+"/"+str(years1[len(years1)-1]))
     choicelist1=[]
     for i in range(0,len(vectorS1)):
         choicelist1.append(vectorS1[i][0]+vectorS1[i][3:6]+vectorS1[i][8:10])
-
-    for k in range(0,(len(years2))-2): 
-        c2=(df['antiguedad'] >=years2[k]) & (df['antiguedad'] <years2[k+1])
-        conditionlist2.append(c2)
-    c2=(df['antiguedad'] >=years2[(len(years2))-2]) & (df['antiguedad'] <=years2[(len(years2))-1])
-    conditionlist2.append(c2)
-    for i in range(0,len(years2)-2):
-        vectorS2.append(L[i]+str(years2[i])+"/"+str(years2[i+1]-1))
-    vectorS2.append(L[len(years2)-2]+str(years2[len(years2)-2])+"/"+str(years2[len(years2)-1]))    
-    choicelist2=[]
-    for i in range(0,len(vectorS2)):
-        choicelist2.append(vectorS2[i][0]+vectorS2[i][3:6]+vectorS2[i][8:10])
-    df_=df.copy()
-    df_=df_.astype({"ingreso":'float64','antiguedad':'float64','supCSII':'float64','supTSII':'float64','valor':'float64',"avaluofiscal": "float64"})
     df.insert(df.shape[1],'Index_antiguedad_10',np.select(conditionlist1, choicelist1, default=0))
-    df.insert(df.shape[1],'Index_antiguedad_5',np.select(conditionlist2, choicelist2, default=0))
     df2=df.astype({"ingreso":"float64",'antiguedad':'float64','supCSII':'float64','supTSII':'float64','valor':'float64',"avaluofiscal": "float64"})
     return df2
-# Gráfica de boxplots
-def grafico_boxplot_rcParams(interval,df2):
-    if interval==10:
-        plt.rcParams['figure.figsize'] = (9,6);
-        sns.boxplot(data=df2.sort_values(by=['Index_antiguedad_10'],
-                  ascending=True, inplace=False), 
-                  x="Index_antiguedad_10", y="valor",
-                  showfliers=False,palette="Set2");
-        sns.stripplot(data=df2.sort_values(by=['Index_antiguedad_10'], 
-                  ascending=True, inplace=False), 
-                  x="Index_antiguedad_10", y="valor",
-                  linewidth=1.0,palette="Set2");
-        plt.xlabel('Década')
-        plt.ylabel('Valor UF')
-        plt.title('Distribución valor UF por década')
-        plt.grid(True, color='lightgrey',linestyle='--')
-        plt.show()
-    elif interval==5:
-        plt.rcParams['figure.figsize'] = (9,5);
-        sns.boxplot(
-                  data=df2.sort_values(by=['Index_antiguedad_5'], 
-                  ascending=True, inplace=False), 
-                  x="Index_antiguedad_5", y="valor",
-                  showfliers=False,palette="Set2");
-        sns.stripplot(data=df2.sort_values(by=['Index_antiguedad_5'], 
-                  ascending=True, inplace=False), 
-                  x="Index_antiguedad_5", y="valor",
-                  linewidth=1.0,palette="Set2");
 
-        plt.xlabel('Periodo 5 años')
-        plt.ylabel('Valor UF')
-        plt.title('Distribución valor UF cada 5 años')
-        plt.grid(True, color='lightgrey',linestyle='--')
-        plt.show()
+# Gráfica de boxplots
+def grafico_boxplot_rcParams(df2):
+    plt.rcParams['figure.figsize'] = (9,6);
+    sns.boxplot(data=df2.sort_values(by=['Index_antiguedad_10'],
+              ascending=True, inplace=False), 
+              x="Index_antiguedad_10", y="valor",
+              showfliers=False,palette="Set2");
+    sns.stripplot(data=df2.sort_values(by=['Index_antiguedad_10'], 
+              ascending=True, inplace=False), 
+              x="Index_antiguedad_10", y="valor",
+              linewidth=1.0,palette="Set2");
+    plt.xlabel('Década')
+    plt.ylabel('Valor UF')
+    plt.title('Distribución valor UF por década')
+    plt.grid(True, color='lightgrey',linestyle='--')
+    plt.show()
 
 def GraEstModels(e,f,g,h): ##### MODIFICADA POR TENER REGRESION Y ENET #####
     xvec=list(e)
@@ -514,12 +475,12 @@ def porcentajeerror(a,b): # a: y_test, b: y_pred
     return tabla
 
 def Entrenamiento(df2, t_s):
-    Xrlinter = np.array(df2[["ingreso",'Index_antiguedad_10','longitud','latitud','supCSII','supTSII',"avaluofiscal"]])
+    df3=df2.drop(['valor'],axis=1)
+    Xrlinter = np.array(df3)
     yrlinter = np.array(df2.valor)
     Xrlinter_train, Xrlinter_test, yrlinter_train, yrlinter_test = train_test_split(Xrlinter, yrlinter, test_size=t_s)
     return Xrlinter_train, Xrlinter_test, yrlinter_train, yrlinter_test, Xrlinter
 
-
 def Escalas(cve, Xrlinter_train, Xrlinter_test):
     scl = StandardScaler().fit(Xrlinter_train)
     Xrlinter_train = scl.transform(Xrlinter_train)  
